@@ -90,20 +90,20 @@ void ShortcutComboBox::keyPressEvent(QKeyEvent *e)
 
 void ShortcutComboBox::focusInEvent(QFocusEvent *e)
 {
-	Q_UNUSED(e);
+	Q_UNUSED(e)
 	this->lineEdit()->selectAll();
 }
 
 
 ShortcutDelegate::ShortcutDelegate(QObject *parent): treeWidget(nullptr)
 {
-	Q_UNUSED(parent);
+	Q_UNUSED(parent)
 }
 QWidget *ShortcutDelegate::createEditor(QWidget *parent,
                                         const QStyleOptionViewItem &option ,
                                         const QModelIndex &index) const
 {
-	Q_UNUSED(option);
+	Q_UNUSED(option)
 
     if (!index.isValid()) return nullptr;
 	const QAbstractItemModel *model = index.model();
@@ -244,7 +244,7 @@ void ShortcutDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 				if (UtilsUi::txsConfirmWarning(QString(ConfigDialog::tr("The shortcut <%1> is already assigned to the command:")).arg(value) + "\n" + duplicate + "\n\n" + ConfigDialog::tr("Do you wish to remove the old assignment and bind the shortcut to the new command?"))) {
 					//model->setData(mil[0],"",Qt::DisplayRole);
 					foreach (QTreeWidgetItem *twi, li) {
-						if (twi and twi->text(2) == value) twi->setText(2, "");
+						if (twi && twi->text(2) == value) twi->setText(2, "");
 					}
 				} else {
 					return;
@@ -386,6 +386,14 @@ int ConfigDialog::lastUsedPage = 0;
 
 ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent), checkboxInternalPDFViewer(nullptr), riddled(false), oldToolbarIndex(-1), mBuildManager(nullptr)
 {
+    // adapt icon size to dpi
+#if QT_VERSION> 0x050000
+    double dpi=QGuiApplication::primaryScreen()->logicalDotsPerInch();
+    double scale=dpi/96;
+#else
+    double scale=1;
+#endif
+
 	setModal(true);
 	ui.setupUi(this);
 
@@ -413,7 +421,7 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent), checkboxInternalPD
 
     ui.checkBoxShowCommentedElementsInStructure->setVisible(false); // hide non-functional option, maybe it can be fixed in future
 
-	ui.contentsWidget->setIconSize(QSize(32, 32));
+    ui.contentsWidget->setIconSize(QSize(qRound(32*scale), qRound(32*scale)));
 	//ui.contentsWidget->setViewMode(QListView::ListMode);
 	//ui.contentsWidget->setMovement(QListView::Static);
 
@@ -525,7 +533,7 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent), checkboxInternalPD
 
 	// custom toolbars
 	connect(ui.comboBoxToolbars, SIGNAL(currentIndexChanged(int)), SLOT(toolbarChanged(int)));
-	ui.listCustomToolBar->setIconSize(QSize(22, 22));
+    ui.listCustomToolBar->setIconSize(QSize(qRound(22*scale), qRound(22*scale)));
 	ui.listCustomToolBar->setViewMode(QListView::ListMode);
 	ui.listCustomToolBar->setMovement(QListView::Snap);
 	ui.listCustomToolBar->setDragDropMode(QAbstractItemView::InternalMove);
@@ -989,8 +997,11 @@ void ConfigDialog::actionsChanged(int actionClass)
 	}
 
 	const QList<QMenu *> &menus = (actionClass == 0) ? standardToolbarMenus : allMenus;
-	foreach (const QMenu *menu, menus)
+    foreach (const QMenu *menu, menus){
+        if(menu->objectName().startsWith("pdf"))
+            continue; // filter out menus for pdf viewer
         populatePossibleActions(nullptr, menu, actionClass != 0);
+    }
 }
 
 void ConfigDialog::toToolbarClicked()
