@@ -10,25 +10,25 @@ class FileDialog
 {
 public:
 
-  static QString getOpenFileName(QWidget *parent = 0,
+  static QString getOpenFileName(QWidget *parent = nullptr,
                                  const QString &caption = QString(),
                                  const QString &dir = QString(),
                                  const QString &filter = QString(),
-                                 QString *selectedFilter = 0,
+                                 QString *selectedFilter = nullptr,
                                  int options = 0);
 
-  static QString getSaveFileName(QWidget *parent = 0,
+  static QString getSaveFileName(QWidget *parent = nullptr,
                                  const QString &caption = QString(),
                                  const QString &dir = QString(),
                                  const QString &filter = QString(),
-                                 QString *selectedFilter = 0,
+                                 QString *selectedFilter = nullptr,
                                  int options = 0);
 
-  static QStringList getOpenFileNames(QWidget *parent = 0,
+  static QStringList getOpenFileNames(QWidget *parent = nullptr,
                                       const QString &caption = QString(),
                                      const QString &dir = QString(),
                                       const QString &filter = QString(),
-                                      QString *selectedFilter = 0,
+                                      QString *selectedFilter = nullptr,
                                       int options = 0);
 };
 
