@@ -29,6 +29,16 @@ struct ReferencePair {
 };
 
 
+struct UserCommandPair {
+	// name of command ("\command") or environment ("environment"),
+	// null string for other user definitions (e.g. newcolumntype, definecolor)
+	QString name;
+	// information for code completion
+	CodeSnippet snippet;
+	UserCommandPair(const QString &name, const CodeSnippet &snippet);
+};
+
+
 /*! \brief extended QDocument
  *
  * Extended document for handling latex documents
@@ -83,12 +93,7 @@ public:
 	Q_INVOKABLE QStringList labelItems() const; ///< all labels in this document
 	Q_INVOKABLE QStringList refItems() const; ///< all references in this document
 	Q_INVOKABLE QStringList bibItems() const; ///< all bibitem defined in this document
-    Q_INVOKABLE QList<CodeSnippet> userCommandList() const ///< all user commands defined in this document
-	{
-		QList<CodeSnippet> csl = mUserCommandList.values();
-		qSort(csl);
-		return csl;
-	}
+	Q_INVOKABLE QList<CodeSnippet> userCommandList() const; ///< all user commands defined in this document, sorted
 	Q_INVOKABLE CodeSnippetList additionalCommandsList();
 	void updateRefsLabels(const QString &ref);
 	void recheckRefsLabels();
@@ -100,7 +105,9 @@ public:
 	Q_INVOKABLE QMultiHash<QDocumentLineHandle *, int> getLabels(const QString &name); ///< get line/column from label name
 	Q_INVOKABLE QMultiHash<QDocumentLineHandle *, int> getRefs(const QString &name); ///< get line/column from reference name
 	Q_INVOKABLE QMultiHash<QDocumentLineHandle *, int> getBibItems(const QString &name);
-    Q_INVOKABLE void replaceItems(QMultiHash<QDocumentLineHandle *, ReferencePair> items, const QString &newName, QDocumentCursor *cursor = nullptr);
+	Q_INVOKABLE QDocumentLineHandle *findCommandDefinition(const QString &name); ///< get line of definition from command name (may return nullptr)
+	Q_INVOKABLE QDocumentLineHandle *findUsePackage(const QString &name); ///< get line of \usepackage from package name (may return nullptr)
+	Q_INVOKABLE void replaceItems(QMultiHash<QDocumentLineHandle *, ReferencePair> items, const QString &newName, QDocumentCursor *cursor = nullptr);
     Q_INVOKABLE void replaceLabel(const QString &name, const QString &newName, QDocumentCursor *cursor = nullptr);
     Q_INVOKABLE void replaceRefs(const QString &name, const QString &newName, QDocumentCursor *cursor = nullptr);
 	Q_INVOKABLE void replaceLabelsAndRefs(const QString &name, const QString &newName);
@@ -147,6 +154,7 @@ public:
 
 	Q_INVOKABLE bool containsPackage(const QString &name);
 	Q_INVOKABLE QStringList containedPackages();
+	Q_INVOKABLE QSet<QString> usedPackages();
 	bool updateCompletionFiles(bool forceUpdate, bool forceLabelUpdate = false, bool delayUpdate = false);
 	const QSet<QString> &getCWLFiles() const;
 
@@ -208,7 +216,7 @@ private:
 	QMultiHash<QDocumentLineHandle *, ReferencePair> mBibItem;
 	QMultiHash<QDocumentLineHandle *, ReferencePair> mRefItem;
 	QMultiHash<QDocumentLineHandle *, FileNamePair> mMentionedBibTeXFiles;
-	QMultiHash<QDocumentLineHandle *, CodeSnippet> mUserCommandList;
+	QMultiHash<QDocumentLineHandle *, UserCommandPair> mUserCommandList;
 	QMultiHash<QDocumentLineHandle *, QString> mUsepackageList;
 	QMultiHash<QDocumentLineHandle *, QString> mIncludedFilesList;
 
@@ -226,15 +234,16 @@ private:
 	void updateContext(QDocumentLineHandle *oldLine, QDocumentLineHandle *newLine, StructureEntry::Context context);
 	void setContextForLines(StructureEntry *se, int startLine, int endLine, StructureEntry::Context context, bool state);
 
-	void findStructureEntryBefore(QMutableListIterator<StructureEntry *> &iter, QMultiHash<QDocumentLineHandle *, StructureEntry *> &MapOfElemnts, int linenr, int count);
+	int findStructureParentPos(const QList<StructureEntry *> &children, QList<StructureEntry *> &removedElements, int linenr, int count);
 
+	bool IsInTree (StructureEntry *se);
 	void updateElementWithSignal(StructureEntry *se){ emit updateElement(se); }
 	void removeElementWithSignal(StructureEntry *se);
 	void addElementWithSignal(StructureEntry *parent, StructureEntry *se);
 	void insertElementWithSignal(StructureEntry *parent, int pos, StructureEntry *se);
 	void moveElementWithSignal(StructureEntry *se, StructureEntry *parent, int pos);
 
-	void addMagicComment(const QString &text, int lineNr, QMultiHash<QDocumentLineHandle *, StructureEntry *> &MapOfMagicComments, QMutableListIterator<StructureEntry *> &iter_magicComment);
+	void addMagicComment(const QString &text, int lineNr, int posMagicComment);
 	void parseMagicComment(const QString &name, const QString &val, StructureEntry *se);
 
 	void gatherCompletionFiles(QStringList &files, QStringList &loadedFiles, LatexPackage &pck, bool gatherForCompleter = false);
