@@ -64,7 +64,7 @@ void LatexPackage::unite(LatexPackage &add, bool forCompletion)
 	environmentAliases.unite(add.environmentAliases);
 	specialTreatmentCommands.unite(add.specialTreatmentCommands);
 	specialDefCommands.unite(add.specialDefCommands);
-    commandDescriptions.unite(add.commandDescriptions); // overloaded unit, which does not overwrite well defined CDs with poorly defined ones
+	commandDescriptions.unite(add.commandDescriptions); // overloaded unit, which does not overwrite well defined CDs with poorly defined ones
 
 	//possibleCommands.unite(add.possibleCommands);
 	foreach (const QString &elem, add.possibleCommands.keys()) { //expensive
@@ -136,13 +136,16 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 
 			if (!keyvals.isEmpty()) {
 				// read keyval (name stored in "keyvals")
-				package.possibleCommands["key%" + keyvals] << line;
+				QStringList l_cmds=keyvals.split(',');
 				QString key;
 				CommandDescription cd = extractCommandDefKeyVal(line, key);
-				if (cd.args > 0) {
-					if (key.endsWith("="))
-						key.chop(1);
-					package.commandDescriptions.insert(keyvals + "/" + key, cd);
+				for(const QString &elem:l_cmds){
+					package.possibleCommands["key%" + elem] << line;
+					if (cd.args > 0) {
+						if (key.endsWith("="))
+							key.chop(1);
+						package.commandDescriptions.insert(elem + "/" + key, cd);
+					}
 				}
 				continue;
 			}
@@ -205,11 +208,11 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 
 				// get commandDefinition
 				CommandDescription cd = extractCommandDef(line, valid);
-                if(valid.contains('K')){
-                    // bracket command like \left etc
-                    cd.bracketCommand=true;
-                    valid.remove("K");
-                }
+				if(valid.contains('K')){
+					// bracket command like \left etc
+					cd.bracketCommand=true;
+					valid.remove("K");
+				}
 				QString cmd = rxCom3.cap(1);
 				if (cmd == "\\begin") {
 					if (!package.commandDescriptions.contains(cmd)) {
@@ -226,6 +229,9 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 					if (cd_old.args == cd.args && cd_old.optionalArgs > cd.optionalArgs ) {
 						cd = cd_old;
 					}
+					if (cd_old.args == cd.args && cd_old.optionalArgs == cd.optionalArgs && cd_old.overlayArgs > cd.overlayArgs ) {
+						cd = cd_old;
+					}
 					if (cd_old.args < cd.args && cd_old.args > 0) {
 						cd = cd_old;
 #ifndef QT_NO_DEBUG
@@ -249,12 +255,12 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 					}
 
 				}
-                if(!valid.contains('M')){
-                    package.commandDescriptions.insert(cmd, cd);
-                }else{
-                    // don't use line for command description
-                    valid.remove('M');
-                }
+				if(!valid.contains('M')){
+					package.commandDescriptions.insert(cmd, cd);
+				}else{
+					// don't use line for command description
+					valid.remove('M');
+				}
 
 
 				valid.remove('N'); // remove newtheorem declaration
@@ -621,10 +627,12 @@ Token::TokenType tokenTypeFromCwlArg(QString arg, QString definition)
 		if (suffix == "%plain") return Token::generalArg;
 		if (suffix == "%text") return Token::text;
 		if (suffix == "%title") return Token::title;
+		if (suffix == "%short title") return Token::shorttitle;
 		if (suffix == "%todo") return Token::todo;
 		if (suffix == "%l") return Token::width;
 		if (suffix == "%cmd") return Token::def;
 		if (suffix == "%keyvals") return Token::keyValArg;
+		if ((suffix == "%envname") && definition.contains('N')) return Token::newTheorem;
 		if (suffix == "%ref") return Token::labelRef;
 		if (suffix == "%labeldef") return Token::label;
 		if (suffix == "%special") {
@@ -643,8 +651,8 @@ Token::TokenType tokenTypeFromCwlArg(QString arg, QString definition)
 	}
 	// type from name
 	if (arg == "text") return Token::text;
-    if (arg == "title") return Token::title;
-    if (arg == "short title" ) return Token::shorttitle;
+	if (arg == "title") return Token::title;
+	if (arg == "short title" ) return Token::shorttitle;
 	if (arg == "package") return Token::package;
 	if (arg == "cols" || arg == "preamble") return Token::colDef;
 	if (arg == "color") return Token::color;
@@ -662,7 +670,7 @@ Token::TokenType tokenTypeFromCwlArg(QString arg, QString definition)
 	if (arg.contains("keys") || arg == "keyvals" || arg == "%<options%>") return Token::keyValArg;
 	if (arg == "options") return Token::packageoption;
 	if (arg == "class") return Token::documentclass;
-    if (arg == "formula") return Token::formula;
+	if (arg == "formula") return Token::formula;
 	if (arg == "beamertheme") return Token::beamertheme;
 	if (arg == "keylist" || arg == "bibid") return Token::bibItem;
 	if (arg == "placement" || arg == "position") return Token::placement;
@@ -672,6 +680,7 @@ Token::TokenType tokenTypeFromCwlArg(QString arg, QString definition)
 	if ((arg == "label" || arg == "%<label%>") && definition.contains('r')) return Token::labelRef;  // reference with keyword label
 	if ((arg == "label" || arg == "%<label%>") && definition.contains('l')) return Token::label;
 	if (arg == "labellist") return Token::labelRefList;
+	if (arg.contains("overlay specification")) return Token::overlay;
 	return Token::generalArg;
 }
 
@@ -710,6 +719,7 @@ argument name | description
 \em keys,\em keyvals or \em \%<options\%>|key/value list
 \em envname|environment name for \\newtheorem, e.g. \\newtheorem{envname}#N (classification N needs to be present !)
 \em ends with %plain|ignore a special meaning of the key
+\em contains "overlay specification" | beamer overlay specification, usually within <>
 
  * \param line command definition until '#'
  * \param definition context information right of '#'
@@ -721,8 +731,8 @@ CommandDescription extractCommandDef(QString line, QString definition)
 	int i = rxCom.indexIn(line);
 	QString command = rxCom.cap();
 	line = line.mid(command.length());
-	const QString specialChars = "{[(";
-	const QString specialChars2 = "}])";
+	const QString specialChars = "{[(<";
+	const QString specialChars2 = "}])>";
 	CommandDescription cd;
 	if (line.isEmpty())
 		return cd;
@@ -755,6 +765,10 @@ CommandDescription extractCommandDef(QString line, QString definition)
 				cd.bracketArgs = cd.bracketArgs + 1;
 				cd.bracketTypes.append(type);
 				break;
+			case 3:
+				cd.overlayArgs = cd.overlayArgs + 1;
+				cd.overlayTypes.append(type);
+				break;
 			default:
 				break;
 			}
@@ -782,5 +796,9 @@ CommandDescription extractCommandDefKeyVal(QString line, QString &key)
 		cd.args = 1;
 		cd.argTypes << Token::width;
 	}
+	if (vals == "#l") {
+		cd.args = 1;
+		cd.argTypes << Token::label;
+	}
 	return cd;
 }
