@@ -37,7 +37,7 @@ TokenList simpleLexLatexLine(QDocumentLineHandle *dlh)
 	present.dlh = dlh;
 	present.argLevel = 0;
 	QChar verbatimSymbol;
-	const QString specialChars = "{([})]";
+    const QString specialChars = "{([<})]>";
 	int i = 0;
 	for (; i < s.length(); i++) {
 		QChar c = s.at(i);
@@ -114,15 +114,15 @@ TokenList simpleLexLatexLine(QDocumentLineHandle *dlh)
 		}
 
 		int l = specialChars.indexOf(c);
-		if (l > -1 && l < 3) {
+        if (l > -1 && l < 4) {
 			present.type = Token::TokenType(int(Token::openBrace) + l);
 			present.length = 1;
 			lexed.append(present);
 			present.type = Token::none;
 			continue;
 		}
-		if (l > 2) {
-			present.type = Token::TokenType(int(Token::closeBrace) + (l - 3));
+        if (l > 3) {
+            present.type = Token::TokenType(int(Token::closeBrace) + (l - 4));
 			present.length = 1;
 			lexed.append(present);
 			present.type = Token::none;
@@ -166,7 +166,6 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
 	CommandStack oldCommandStack = dlh->getCookie(QDocumentLine::LEXER_COMMANDSTACK_COOKIE).value<CommandStack >();
 	QString line = dlh->text();
 	bool verbatimMode = false;
-    bool verbatimAfterOptionalArg=false;
 	int level = 0;
 	if (!stack.isEmpty()) {
 	    if (stack.top().type == Token::verbatim) {
@@ -343,7 +342,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                         commandStack.pop();
                     }
                 }
-                if (lp.commandDefs.contains(command)) {
+                if (lp.commandDefs.contains(command) && tk.subtype != Token::definition) {
                     CommandDescription cd = lp.commandDefs.value(command);
                     cd.level = level;
                     if(cd.bracketCommand){
@@ -407,6 +406,15 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                         continue;
                     }
                 }
+                if (tk.type == Token::less) {
+                    if (cd.overlayArgs > 0) {
+                        cd.overlayArgs--;
+                        tk.subtype = cd.overlayTypes.takeFirst();
+                    } else {
+                        lexed << tk;
+                        continue;
+                    }
+                }
 
                 tk.level = level; // push old level on stack in order to restore that level later and to distinguish between arguments and arbitrary braces
                 tk.argLevel = ConfigManager::RUNAWAYLIMIT; // run-away prevention
@@ -430,11 +438,11 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
         }
 	    if (Token::tkClose().contains(tk.type)) {
 		// special treament for brackets as they don't have any syntaxtical meaning except with some commands
-            if (tk.type == Token::closeBracket ) {
+            if (tk.type == Token::closeBracket || tk.type == Token::greater ) {
                 if (stack.isEmpty())
                     continue;
                 if (stack.top().type != Token::opposite(tk.type))
-                    continue; //closing bracket is ignored if no correct open is present
+                    continue; //closing bracket/> is ignored if no correct open is present
             }
             if (!stack.isEmpty() && stack.top().type == Token::opposite(tk.type)) {
                 Token tk1 = stack.pop();
@@ -487,7 +495,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                                 if (lp.possibleCommands["%verbatimEnv"].contains(env)) {
                                     if(cd.args==1 && cd.optionalArgs==1){
                                         // special treatment for \begin{abc}[...]
-                                        verbatimAfterOptionalArg=true;
+                                        cd.verbatimAfterOptionalArg=true;
                                         cd.args--;
                                         cd.argTypes.takeFirst();
                                         cd.optionalCommandName="\\begin{" + env + "}";
@@ -539,8 +547,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                     if (cd.args <= 0 && cd.bracketArgs <= 0) {
                         // all args handled, stop handling this command
                         commandStack.pop();
-                        if(verbatimAfterOptionalArg){ // delayed verbatim start to handle optional argument
-                            verbatimAfterOptionalArg=false;
+                        if(cd.verbatimAfterOptionalArg){ // delayed verbatim start to handle optional argument
                             verbatimMode = true;
                             Token tk3;
                             tk3.dlh = dlh;
@@ -742,12 +749,15 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
             }
         }
     }
-    if(verbatimAfterOptionalArg){ //optional arg not found
-        Token tk3;
-        tk3.dlh = dlh;
-        tk3.level = level - 1;
-        tk3.type = Token::verbatim;
-        stack.push(tk3);
+    if (!commandStack.isEmpty() && commandStack.top().level == level) {
+        CommandDescription &cd = commandStack.top();
+        if(cd.verbatimAfterOptionalArg){ //optional arg not found
+            Token tk3;
+            tk3.dlh = dlh;
+            tk3.level = level - 1;
+            tk3.type = Token::verbatim;
+            stack.push(tk3);
+        }
     }
 
     dlh->setCookie(QDocumentLine::LEXER_COOKIE, QVariant::fromValue<TokenList>(lexed));
