@@ -33,19 +33,28 @@ class QDocument;
 class Token
 {
 public:
-	Token(): start(-1), length(-1), level(-1), dlh(0), type(none), subtype(none), argLevel(0) {}
+	Token(): start(-1), length(-1), level(-1), dlh(nullptr), type(none), subtype(none), argLevel(0) {}
 	int start;
 	int length;
 	int level;
-    QString optionalCommandName;
+	QString optionalCommandName;
 	QDocumentLineHandle *dlh;
 
-	enum TokenType {none = 0, word, command, braces, bracket,
-	                squareBracket, openBrace, openBracket, openSquare, closeBrace,
-	                closeBracket, closeSquareBracket, math, comment, commandUnknown, label, bibItem, file, imagefile, bibfile,
-                    keyValArg, keyVal_key, keyVal_val, list, text, env, beginEnv, def, labelRef, package, width, placement, colDef, title,shorttitle, todo, url, documentclass, beamertheme, packageoption,
-                    color, verbatimStart, verbatimStop, verbatim, symbol, punctuation, number, generalArg, defArgNumber, optionalArgDefinition, definition, defWidth, labelRefList, specialArg, newTheorem,newBibItem,formula,_end = 255
-	               };
+	enum TokenType {
+		none = 0, word, command, braces, bracket,
+		squareBracket, openBrace, openBracket, openSquare, less,
+		closeBrace, closeBracket, closeSquareBracket, greater, math,
+		comment, commandUnknown, label, bibItem, file,
+		imagefile, bibfile, keyValArg, keyVal_key, keyVal_val,
+		list, text, env, beginEnv, def,
+		labelRef, package, width, placement, colDef,
+		title, shorttitle, todo, url, documentclass,
+		beamertheme, packageoption, color, verbatimStart, verbatimStop,
+		verbatim, symbol, punctuation, number, generalArg,
+		defArgNumber, optionalArgDefinition, definition, defWidth, labelRefList,
+		specialArg, newTheorem, newBibItem, formula, overlay,
+		overlayRegion, _end = 255
+	};
 	static QString tokenTypeName(TokenType t);
 
 	TokenType type;
