@@ -64,7 +64,7 @@ void MathAssistant::processError(QProcess::ProcessError err)
 
 void MathAssistant::processFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-	Q_UNUSED(exitCode);
+	Q_UNUSED(exitCode)
 	if (exitStatus != QProcess::NormalExit) {
 		UtilsUi::txsCritical(tr("TexTablet crashed."));
 	}
