@@ -36,6 +36,7 @@
 
 #include "PDFDocks.h"
 #include "PDFDocument.h"
+#include "universalinputdialog.h"
 
 /*!
  * \brief constructor
@@ -70,6 +71,13 @@ void PDFDock::pageChanged(int page)
 	Q_UNUSED(page)
 }
 
+void PDFDock::addAction(const QString& caption, const char* slot)
+{
+	QAction *act = new QAction(caption, this);
+	connect(act, SIGNAL(triggered()), slot);
+	addAction(act);
+}
+
 void PDFDock::myVisibilityChanged(bool visible)
 {
 	setWindowTitle(getTitle());
@@ -88,7 +96,7 @@ void PDFDock::changeLanguage()
 
 static void fillToc(const QDomNode &parent, QTreeWidget *tree, QTreeWidgetItem *parentItem)
 {
-	QTreeWidgetItem *newitem = 0;
+    QTreeWidgetItem *newitem = nullptr;
 	for (QDomNode node = parent.firstChild(); !node.isNull(); node = node.nextSibling()) {
 		QDomElement e = node.toElement();
 
@@ -152,7 +160,7 @@ void PDFOutlineDock::fillInfo()
 	if (!document || document->popplerDoc().isNull()) return;
 	const QDomDocument *toc = document->popplerDoc()->toc();
 	if (toc) {
-		fillToc(*toc, tree, 0);
+        fillToc(*toc, tree, nullptr);
 		connect(tree, SIGNAL(itemClicked(QTreeWidgetItem *, int)), this, SLOT(followTocSelection()));
 		delete toc;
 	} else {
@@ -227,7 +235,7 @@ void PDFInfoDock::fillInfo()
 		const int id = keys.indexOf(date);
 		if (id != -1) {
 			list->addItem(date + ":");
-			list->addItem(doc->date(date).toString(Qt::SystemLocaleDate));
+			list->addItem(doc->date(date).toLocalTime().toString(Qt::SystemLocaleDate));
 			++i;
 			keys.removeAt(id);
 		}
@@ -269,7 +277,7 @@ QSize PDFDockListWidget::sizeHint() const
 PDFOverviewModel::PDFOverviewModel(QObject *parent)
 	: QAbstractListModel(parent)
 {
-	document = 0;
+    document = nullptr;
 	cache.clear();
 }
 
@@ -308,7 +316,7 @@ void PDFOverviewModel::setDocument(PDFDocument *doc)
 		endResetModel();
 		return;
 	}
-	if (!doc->widget() || document->popplerDoc().isNull()) document = 0;
+    if (!doc->widget() || document->popplerDoc().isNull()) document = nullptr;
 	cache.clear();
 	endResetModel();
 }
@@ -495,8 +503,8 @@ PDFBaseSearchDock::PDFBaseSearchDock(PDFDocument *doc): QDockWidget(doc), docume
 
 	// set texts
 	leFind->setToolTip(tr("Text or pattern to search for"));
-	bNext->setToolTip(tr("Find next occurence"));
-	bPrevious->setToolTip(tr("Find previous occurence"));
+    bNext->setToolTip(tr("Find next occurrence"));
+    bPrevious->setToolTip(tr("Find previous occurrence"));
 
 	label->setText(tr(" Find :"));
 	label->setMinimumWidth(label->sizeHint().width());
@@ -630,7 +638,7 @@ bool PDFSearchDock::hasFlagSync() const
 //////////////// SCROLL AREA ////////////////
 
 PDFScrollArea::PDFScrollArea(QWidget *parent)
-	: QAbstractScrollArea(parent), continuous(true), pdf(0), updateWidgetPositionStackWatch(0), onResizeStackWatch(0)
+    : QAbstractScrollArea(parent), continuous(true), pdf(nullptr), updateWidgetPositionStackWatch(0), onResizeStackWatch(0)
 {
 	viewport()->setBackgroundRole(QPalette::NoRole);
 	viewport()->setAttribute(Qt::WA_AcceptTouchEvents, true);
@@ -643,8 +651,8 @@ void PDFScrollArea::setPDFWidget(PDFWidget *widget)
 {
 	//from qt
 	if (pdf == widget) return;
-	if (pdf) delete pdf;
-	pdf = 0;
+    delete pdf;
+    pdf = nullptr;
 	horizontalScrollBar()->setValue(0);
 	verticalScrollBar()->setValue(0);
 	if (widget->parentWidget() != viewport())
@@ -696,7 +704,7 @@ void PDFScrollArea::setContinuous(bool cont)
 	if (!cont) pdf->setGridSize(pdf->gridCols(), 1);
 	else {
 		int page = pdf->getPageIndex();
-		resizeEvent(0);
+        resizeEvent(nullptr);
 		goToPage(page, false);
 	}
 }
@@ -749,7 +757,7 @@ bool PDFScrollArea::eventFilter(QObject *o, QEvent *e)
 
 void PDFScrollArea::wheelEvent(QWheelEvent *e)
 {
-	if (pdf && !getContinuous()) {
+    if (pdf){// && !getContinuous()) {
 		pdf->wheelEvent(e);
 		return;
 	}
@@ -832,11 +840,6 @@ void PDFScrollArea::updateScrollBars()
 
 
 //////////////// Overview ////////////////
-struct renderInfo {
-	Poppler::Page *page;
-	PDFWidget *widget;
-};
-
 
 PDFOverviewDock::PDFOverviewDock(PDFDocument *doc)
 	: PDFDock(doc), toGenerate(0)
@@ -876,7 +879,7 @@ void PDFOverviewDock::fillInfo()
 
 void PDFOverviewDock::documentClosed()
 {
-	qobject_cast<PDFOverviewModel *>(list->model())->setDocument(0);
+    qobject_cast<PDFOverviewModel *>(list->model())->setDocument(nullptr);
 	PDFDock::documentClosed();
 }
 
@@ -910,12 +913,8 @@ PDFClockDock::PDFClockDock(PDFDocument *parent): PDFDock(parent)
 	timer->start(2000);
 
 	setContextMenuPolicy(Qt::ActionsContextMenu);
-	QAction *act = new QAction(tr("Set Interval..."), this);
-	connect(act, SIGNAL(triggered()), SLOT(setInterval()));
-	addAction(act);
-	act = new QAction(tr("Restart"), this);
-	connect(act, SIGNAL(triggered()), SLOT(restart()));
-	addAction(act);
+	addAction(tr("Set Interval..."),  SLOT(setInterval()));
+	addAction(tr("Restart"), SLOT(restart()));
 }
 
 PDFClockDock::~PDFClockDock()
@@ -941,7 +940,7 @@ void PDFClockDock::onTimer()
 
 void PDFClockDock::restart()
 {
-	int delta = start.secsTo(end);
+    qint64 delta = start.secsTo(end);
 	start = QDateTime::currentDateTime();
 	end = start.addSecs(delta);
 	update();
@@ -949,10 +948,18 @@ void PDFClockDock::restart()
 
 void PDFClockDock::setInterval()
 {
-	bool ok;
-	int interval = QInputDialog::getInt(0, "TeXstudio", tr("New clock interval (in minutes)"), 60, 1, 9999, 5, &ok);
-	if (!ok) return;
-	setInterval(interval);
+	int i = (start.secsTo(end) + 30) / 60;
+	QString s = start.time().toString();
+	UniversalInputDialog d;
+	d.addVariable(&s, tr("Start time"));
+	QSpinBox* sb = d.addVariable(&i, tr("New clock interval (in minutes)"));
+	sb->setMinimum(1);
+	sb->setMaximum(9999);
+
+	if (!d.exec()) return;
+	start = QDateTime::currentDateTime();
+	start.setTime( QTime::fromString(s) );
+	end = start.addSecs(i * 60);
 }
 
 void PDFClockDock::setInterval(int interval)
@@ -982,12 +989,15 @@ void PDFClockDock::paintEvent(QPaintEvent *event)
 	p.fillRect(r, backgroundBrush);
 
 	// text
+	qint64 pendingSeconds = start.secsTo(QDateTime::currentDateTime());
 	qint64 remainingSeconds = QDateTime::currentDateTime().secsTo(end);
 	QString text;
-	if (remainingSeconds <= 60)
-		text = tr("%1 sec").arg(qMax(qint64(0), remainingSeconds));
+	if (pendingSeconds < 0)
+		text = tr("wait");
+	else if (remainingSeconds <= 90)
+		text = tr("%1 sec").arg(qMax<qint64>(0, remainingSeconds));
 	else
-		text = tr("%1 min").arg(remainingSeconds / 60);
+		text = tr("%1 min").arg((remainingSeconds + 30) / 60);
 	QFont f = p.font();
 	f.setPixelSize(r.height());
 	p.setFont(f);
@@ -999,12 +1009,12 @@ void PDFClockDock::paintEvent(QPaintEvent *event)
 
 	// progress bar
 	r.adjust(labelWidth, 0, 0, 0);
-	p.fillRect(r.x(), 0, r.width() * start.secsTo(QDateTime::currentDateTime()) / qMax(qint64(start.secsTo(end)), qint64(1)), r.height() * 3 / 4, timeBarColor);
+	p.fillRect(r.x(), 0, qMax<int>(0, r.width() * pendingSeconds / qMax(qint64(start.secsTo(end)), qint64(1))), r.height() * 3 / 4, timeBarColor);
 	p.fillRect(r.x(), r.height() * 3 / 4, r.width() * document->widget()->getPageIndex() / qMax(1, document->widget()->realNumPages() - 1),  r.height() / 4, pagesBarColor);
 }
 
 
-MessageFrame::MessageFrame(QWidget *parent) : QFrame(parent), label(0)
+MessageFrame::MessageFrame(QWidget *parent) : QFrame(parent), label(nullptr)
 {
 	QHBoxLayout *layout = new QHBoxLayout();
 	setLayout(layout);
@@ -1013,7 +1023,8 @@ MessageFrame::MessageFrame(QWidget *parent) : QFrame(parent), label(0)
 	layout->addWidget(label);
 	layout->setContentsMargins(2, 2, 2, 2);
 
-	setStyleSheet("background: #FFFBBF;");
+	setStyleSheet("MessageFrame {background: #FFFBBF}\n"
+				  "QLabel {color: black}");  // only style the frame and the labels. Buttons remain unstyled.
 	setVisible(false);
 }
 
