@@ -70,19 +70,19 @@ QStringList findHistory, replaceHistory;
 	\brief Constructor
 */
 QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
-    : QPanel(p),m_search(nullptr),m_lastDirection(false),useLineForSearch(false),searchOnlyInSelection(false)
+  : QPanel(p),m_search(nullptr),m_lastDirection(false),useLineForSearch(false),searchOnlyInSelection(false)
 {
 	setObjectName("searchPanel");
 	
 	ConfigManagerInterface* conf = ConfigManagerInterface::getInstance();
 	//setupUi(this);
 	// do it completely programatic
-    //this->resize(801, 21);
-    QVBoxLayout *vboxLayout=new QVBoxLayout(this);
-    QWidget *searchWidget=new QWidget(nullptr);
-    //searchWidget->setSizePolicy(QSizePolicy::Preferred,QSizePolicy::MinimumExpanding);
-    vboxLayout->addWidget(searchWidget);
-    FlowLayoutX *flowLayout=new FlowLayoutX(searchWidget,1,1,1);
+	//this->resize(801, 21);
+	QVBoxLayout *vboxLayout=new QVBoxLayout(this);
+	QWidget *searchWidget=new QWidget(nullptr);
+	//searchWidget->setSizePolicy(QSizePolicy::Preferred,QSizePolicy::MinimumExpanding);
+	vboxLayout->addWidget(searchWidget);
+	FlowLayoutX *flowLayout=new FlowLayoutX(searchWidget,1,1,1);
 
 	QSize buttonSize(22,22);
 
@@ -94,13 +94,13 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	bClose->setMaximumSize(buttonSize);
 	QIcon closeIcon = getRealIconCached("close-tab");
 	closeIcon.addFile(":/images-ng/close-tab-hover.svgz", QSize(), QIcon::Active);
-    bClose->setIcon(closeIcon);
-    flowLayout->addWidget(bClose);
+	bClose->setIcon(closeIcon);
+	flowLayout->addWidget(bClose);
 
 	QLabel* lbFind = new QLabel(this);
 	lbFind->setObjectName(("lbFind"));
 	lbFind->setMinimumHeight(buttonSize.height());
-    flowLayout->addWidget(lbFind);
+	flowLayout->addWidget(lbFind);
 
 	cFind = new QComboBox(this);
 	cFind->setEditable(true);
@@ -110,135 +110,155 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	cFind->completer()->setCompletionMode(QCompleter::PopupCompletion);
 	cFind->completer()->setCaseSensitivity(Qt::CaseSensitive);
 	cFind->setObjectName(("cFind"));
-    QSizePolicy sizePolicy4(QSizePolicy::Expanding, QSizePolicy::Fixed);
+	QSizePolicy sizePolicy4(QSizePolicy::Expanding, QSizePolicy::Fixed);
 	sizePolicy4.setHorizontalStretch(2);
 	cFind->setSizePolicy(sizePolicy4);
 	cFind->setMinimumSize(QSize(120, 22));
-	conf->registerOption("Search/Find History", &findHistory, QStringList()); 
+	conf->registerOption("Search/Find History", &findHistory, QStringList());
 	conf->linkOptionToObject(&findHistory, cFind, LinkOptions(LO_UPDATE_ALL | LO_DIRECT_OVERRIDE));
-    flowLayout->addWidget(cFind);
+	flowLayout->addWidget(cFind);
 
-    buttonSize.setHeight(cFind->height());
-    buttonSize.setWidth(cFind->height());
+	buttonSize.setHeight(cFind->height());
+	buttonSize.setWidth(cFind->height());
 
 
 	bNext = new QToolButton(this);
 	bNext->setObjectName(("bNext"));
 	bNext->setMinimumSize(buttonSize);
 	bNext->setMaximumSize(buttonSize);
-    bNext->setIcon(getRealIconCached("down"));
-    bNext->setIconSize(buttonSize);
-    flowLayout->addWidget(bNext);
+	bNext->setIcon(getRealIconCached("down"));
+	bNext->setIconSize(buttonSize);
+	flowLayout->addWidget(bNext);
 
 	bPrevious = new QToolButton(this);
 	bPrevious->setObjectName(("bPrevious"));
 	bPrevious->setMinimumSize(buttonSize);
 	bPrevious->setMaximumSize(buttonSize);
-    bPrevious->setIcon(getRealIconCached("up"));
-    bPrevious->setIconSize(buttonSize);
-    flowLayout->addWidget(bPrevious);
+	bPrevious->setIcon(getRealIconCached("up"));
+	bPrevious->setIconSize(buttonSize);
+	flowLayout->addWidget(bPrevious);
 
 	bCount = new QToolButton(this);
 	bCount->setObjectName(("bCount"));
 	bCount->setMinimumSize(buttonSize);
 	bCount->setMaximumSize(buttonSize);
-    bCount->setIcon(getRealIconCached("count"));
-    bCount->setIconSize(buttonSize);
-    flowLayout->addWidget(bCount);
+	bCount->setIcon(getRealIconCached("count"));
+	bCount->setIconSize(buttonSize);
+	flowLayout->addWidget(bCount);
 
 	QLabel *spacer = new QLabel("  ");
 	flowLayout->addWidget(spacer);
 
-    //cbCase = new QCheckBox();
-    cbCase = new QToolButton(this);
-    cbCase->setCheckable(true);
+	//cbCase = new QCheckBox();
+	cbCase = new QToolButton(this);
+	cbCase->setCheckable(true);
 	cbCase->setObjectName(("cbCase"));
 	cbCase->setToolTip(tr("Enables case sensitive search."));
-    cbCase->setMinimumSize(buttonSize);
-    cbCase->setMaximumSize(buttonSize);
-    cbCase->setIcon(getRealIconCached("case"));
-    cbCase->setIconSize(buttonSize);
-    CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, caseConfig, false, "Search/Case Sensitive", cbCase);
-    flowLayout->addWidget(cbCase);
+	cbCase->setMinimumSize(buttonSize);
+	cbCase->setMaximumSize(buttonSize);
+	cbCase->setIcon(getRealIconCached("case"));
+	cbCase->setIconSize(buttonSize);
+	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, caseConfig, false, "Search/Case Sensitive", cbCase);
+	flowLayout->addWidget(cbCase);
 
-    cbWords = new QToolButton(this);
-    cbWords->setCheckable(true);
+	cbWords = new QToolButton(this);
+	cbWords->setCheckable(true);
 	cbWords->setToolTip(tr("Only searches for whole words."));
 	cbWords->setObjectName(("cbWords"));
-    cbWords->setMinimumSize(buttonSize);
-    cbWords->setMaximumSize(buttonSize);
-    cbWords->setIcon(getRealIconCached("word"));
-    cbWords->setIconSize(buttonSize);
-    CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, wordConfig, false, "Search/Whole Words", cbWords);
-    flowLayout->addWidget(cbWords);
+	cbWords->setMinimumSize(buttonSize);
+	cbWords->setMaximumSize(buttonSize);
+	cbWords->setIcon(getRealIconCached("word"));
+	cbWords->setIconSize(buttonSize);
+	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, wordConfig, false, "Search/Whole Words", cbWords);
+	flowLayout->addWidget(cbWords);
 
-    cbRegExp = new QToolButton(this);
-    cbRegExp->setCheckable(true);
+	cbRegExp = new QToolButton(this);
+	cbRegExp->setCheckable(true);
 	cbRegExp->setToolTip(tr("This interprets the search text as a regular expression.\nSome common regexps:\n r* will find any amount of r, r+ is equal to rr*, a? will matches a or nothing,\n () groups expressions together, [xyz] will find x,y, or z, . matches everything, \\. matches .\nYou can use \\1 to \\9 in the replace text to insert a submatch."));
 	cbRegExp->setObjectName(("cbRegExp"));
-    cbRegExp->setMinimumSize(buttonSize);
-    cbRegExp->setMaximumSize(buttonSize);
-    cbRegExp->setIcon(getRealIconCached("regex"));
-    cbRegExp->setIconSize(buttonSize);
-    CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, regexConfig, false, "Search/Regular Expression", cbRegExp);
-    flowLayout->addWidget(cbRegExp);
+	cbRegExp->setMinimumSize(buttonSize);
+	cbRegExp->setMaximumSize(buttonSize);
+	cbRegExp->setIcon(getRealIconCached("regex"));
+	cbRegExp->setIconSize(buttonSize);
+	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, regexConfig, false, "Search/Regular Expression", cbRegExp);
+	flowLayout->addWidget(cbRegExp);
 
-    cbHighlight = new QToolButton(this);
-    cbHighlight->setCheckable(true);
+	cbHighlight = new QToolButton(this);
+	cbHighlight->setCheckable(true);
 	cbHighlight->setObjectName(("cbHighlight"));
 	cbHighlight->setToolTip(tr("Highlights search matches and replaced text."));
-    cbHighlight->setIcon(getRealIconCached("highlight"));
-    cbHighlight->setMinimumSize(buttonSize);
-    cbHighlight->setMaximumSize(buttonSize);
-    cbHighlight->setIconSize(buttonSize);
-    CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, highlightConfig, true, "Search/Highlight", cbHighlight);
-    flowLayout->addWidget(cbHighlight);
+	cbHighlight->setIcon(getRealIconCached("highlight"));
+	cbHighlight->setMinimumSize(buttonSize);
+	cbHighlight->setMaximumSize(buttonSize);
+	cbHighlight->setIconSize(buttonSize);
+	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, highlightConfig, true, "Search/Highlight", cbHighlight);
+	flowLayout->addWidget(cbHighlight);
 
-    cbCursor = new QToolButton(this);
-    cbCursor->setCheckable(true);
+	cbCursor = new QToolButton(this);
+	cbCursor->setCheckable(true);
 	cbCursor->setToolTip(tr("Starts the search from the current cursor position."));
-    cbCursor->setObjectName(("cbCursor"));
-    cbCursor->setMinimumSize(buttonSize);
-    cbCursor->setMaximumSize(buttonSize);
-    cbCursor->setIcon(getRealIconCached("cursor"));
-    cbCursor->setIconSize(buttonSize);
-    CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, cursorConfig, true, "Search/Cursor", cbCursor);
-    flowLayout->addWidget(cbCursor);
+	cbCursor->setObjectName(("cbCursor"));
+	cbCursor->setMinimumSize(buttonSize);
+	cbCursor->setMaximumSize(buttonSize);
+	cbCursor->setIcon(getRealIconCached("cursor"));
+	cbCursor->setIconSize(buttonSize);
+	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, cursorConfig, true, "Search/Cursor", cbCursor);
+	flowLayout->addWidget(cbCursor);
 
-    cbSelection = new QToolButton(this);
-    cbSelection->setCheckable(true);
+	cbSelection = new QToolButton(this);
+	cbSelection->setCheckable(true);
 	cbSelection->setToolTip(tr("Only searches in the selected text."));
 	cbSelection->setObjectName(("cbSelection"));
-    cbSelection->setMinimumSize(buttonSize);
-    cbSelection->setMaximumSize(buttonSize);
-    cbSelection->setIcon(getRealIconCached("selection"));
-    cbSelection->setIconSize(buttonSize);
-    CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, selectionConfig, false, "Search/Selection", cbSelection);
-    flowLayout->addWidget(cbSelection);
+	cbSelection->setMinimumSize(buttonSize);
+	cbSelection->setMaximumSize(buttonSize);
+	cbSelection->setIcon(getRealIconCached("selection"));
+	cbSelection->setIconSize(buttonSize);
+	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, selectionConfig, false, "Search/Selection", cbSelection);
+	flowLayout->addWidget(cbSelection);
 
-    bExtend  = new QToolButton(this);
-    bExtend->setToolTip(tr("Extended Search"));
-    bExtend->setObjectName(("bExtend"));
-    bExtend->setMinimumSize(buttonSize);
-    bExtend->setMaximumSize(buttonSize);
-    bExtend->setIcon(getRealIconCached("extend"));
-    bExtend->setIconSize(buttonSize);
-    flowLayout->addWidget(bExtend);
-    connect(bExtend, SIGNAL(clicked()), this, SIGNAL(showExtendedSearch()));
+	cbFilter = new QToolButton(this);
+	cbFilter->setToolTip(tr("Only searches in selected text type (math, commands, etc.)"));
+	cbFilter->setObjectName(("cbFilter"));
+	cbFilter->setMinimumSize(buttonSize);
+	cbFilter->setMaximumSize(buttonSize);
+	QMenu *menu=new QMenu();
+	menu->addAction(getRealIcon("all"),"all",this,SLOT(filterChanged()));
+	menu->addAction(getRealIcon("math"),"math",this,SLOT(filterChanged()));
+	menu->addAction(getRealIcon("verbatim"),"verbatim",this,SLOT(filterChanged()));
+	menu->addAction(getRealIcon("comment"),"comment",this,SLOT(filterChanged()));
+	menu->addAction(getRealIcon("non-comment"),"non-comment",this,SLOT(filterChanged()));
+	menu->addAction(getRealIcon("command"),"keyword",this,SLOT(filterChanged()));
+	menu->addAction(getRealIcon("label"),"label",this,SLOT(filterChanged()));
+	menu->addAction(getRealIcon("cite"),"citation",this,SLOT(filterChanged()));
+	cbFilter->setMenu(menu);
+	cbFilter->setPopupMode(QToolButton::InstantPopup);
+	cbFilter->setIcon(getRealIconCached("all"));
+	cbFilter->setIconSize(buttonSize);
+	flowLayout->addWidget(cbFilter);
+
+	bExtend  = new QToolButton(this);
+	bExtend->setToolTip(tr("Extended Search"));
+	bExtend->setObjectName(("bExtend"));
+	bExtend->setMinimumSize(buttonSize);
+	bExtend->setMaximumSize(buttonSize);
+	bExtend->setIcon(getRealIconCached("extend"));
+	bExtend->setIconSize(buttonSize);
+	flowLayout->addWidget(bExtend);
+	connect(bExtend, SIGNAL(clicked()), this, SIGNAL(showExtendedSearch()));
 
 	// replace section
-    replaceWidget=new QWidget(this);
-    vboxLayout->addWidget(replaceWidget);
-    FlowLayoutX *flowLayout2=new FlowLayoutX(replaceWidget,1,1,1);
+	replaceWidget=new QWidget(this);
+	vboxLayout->addWidget(replaceWidget);
+	FlowLayoutX *flowLayout2=new FlowLayoutX(replaceWidget,1,1,1);
 	QWidget *closeButtonPlaceHolder = new QWidget();  // takes exactly the same amount of space as the close button in the find panel
 	closeButtonPlaceHolder->setMinimumSize(buttonSize);
-    closeButtonPlaceHolder->setMaximumSize(buttonSize);
-    flowLayout2->addWidget(closeButtonPlaceHolder);
+	closeButtonPlaceHolder->setMaximumSize(buttonSize);
+	flowLayout2->addWidget(closeButtonPlaceHolder);
 
 	QLabel *lbReplace = new QLabel(this);
 	lbReplace->setObjectName("lbReplace");
 	lbReplace->setMinimumHeight(buttonSize.height());
-    flowLayout2->addWidget(lbReplace);
+	flowLayout2->addWidget(lbReplace);
 
 	cReplace = new QComboBox(this);
 	cReplace->setEditable(true);
@@ -246,73 +266,73 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	cReplace->lineEdit()->setClearButtonEnabled(true);
 #endif
 	cReplace->completer()->setCompletionMode(QCompleter::PopupCompletion);
-    cReplace->completer()->setCaseSensitivity(Qt::CaseSensitive);
+	cReplace->completer()->setCaseSensitivity(Qt::CaseSensitive);
 	cReplace->setObjectName(("cReplace"));
 	cReplace->setEnabled(true);
 	QSizePolicy sizePolicy7(QSizePolicy::Minimum, QSizePolicy::Fixed);
 	sizePolicy7.setHorizontalStretch(2);
 	sizePolicy7.setVerticalStretch(0);
 	sizePolicy7.setHeightForWidth(cReplace->sizePolicy().hasHeightForWidth());
-    cReplace->setSizePolicy(sizePolicy4);
+	cReplace->setSizePolicy(sizePolicy4);
 	cReplace->setMinimumSize(QSize(120, 22));
-//	cReplace->setMaximumSize(QSize(1200, 16777215));
+	//	cReplace->setMaximumSize(QSize(1200, 16777215));
 	conf->registerOption("Search/Replace History", &replaceHistory, QStringList());
 	conf->linkOptionToObject(&replaceHistory, cReplace, LinkOptions(LO_UPDATE_ALL | LO_DIRECT_OVERRIDE));
-    flowLayout2->addWidget(cReplace);
+	flowLayout2->addWidget(cReplace);
 
-    bReplaceNext = new QToolButton(this);
+	bReplaceNext = new QToolButton(this);
 	bReplaceNext->setObjectName(("bReplaceNext"));
 	bReplaceNext->setMinimumSize(buttonSize);
 	bReplaceNext->setMaximumSize(buttonSize);
-    bReplaceNext->setIcon(getRealIconCached("replacedown"));
-    flowLayout2->addWidget(bReplaceNext);
+	bReplaceNext->setIcon(getRealIconCached("replacedown"));
+	flowLayout2->addWidget(bReplaceNext);
 
 	bReplacePrevious = new QToolButton(this);
 	bReplacePrevious->setObjectName(("bReplacePrevious"));
 	bReplacePrevious->setMinimumSize(buttonSize);
 	bReplacePrevious->setMaximumSize(buttonSize);
-    bReplacePrevious->setIcon(getRealIconCached("replaceup"));
-    flowLayout2->addWidget(bReplacePrevious);
+	bReplacePrevious->setIcon(getRealIconCached("replaceup"));
+	flowLayout2->addWidget(bReplacePrevious);
 
 	bReplaceAll = new QToolButton(this);
 	bReplaceAll->setObjectName(("bReplaceAll"));
 	bReplaceAll->setMinimumSize(buttonSize);
 	bReplaceAll->setMaximumSize(buttonSize);
-    bReplaceAll->setIcon(getRealIconCached("replaceall"));
-    flowLayout2->addWidget(bReplaceAll);
+	bReplaceAll->setIcon(getRealIconCached("replaceall"));
+	flowLayout2->addWidget(bReplaceAll);
 
 	QLabel *spacer2 = new QLabel("  ");
 	flowLayout2->addWidget(spacer2);
 
-    cbPrompt = new QToolButton(this);
-    cbPrompt->setCheckable(true);
+	cbPrompt = new QToolButton(this);
+	cbPrompt->setCheckable(true);
 	cbPrompt->setToolTip(tr("Ask before any match is replaced."));
 	cbPrompt->setObjectName(("cbPrompt"));
-    cbPrompt->setMinimumSize(buttonSize);
-    cbPrompt->setMaximumSize(buttonSize);
-    cbPrompt->setIcon(getRealIconCached("prompt"));
+	cbPrompt->setMinimumSize(buttonSize);
+	cbPrompt->setMaximumSize(buttonSize);
+	cbPrompt->setIcon(getRealIconCached("prompt"));
 	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, askConfig, false, "Search/Ask before Replace", cbPrompt);
-    flowLayout2->addWidget(cbPrompt);
+	flowLayout2->addWidget(cbPrompt);
 
-    cbEscapeSeq = new QToolButton(this);
-    cbEscapeSeq->setCheckable(true);
+	cbEscapeSeq = new QToolButton(this);
+	cbEscapeSeq->setCheckable(true);
 	cbEscapeSeq->setToolTip(tr("Enables the use of escape characters. These are:\n \\n = new line, \\r = carriage return, \\t = tab, \\\\ = \\"));
 	cbEscapeSeq->setObjectName(("cbEscapeSeq"));
-    cbEscapeSeq->setMinimumSize(buttonSize);
-    cbEscapeSeq->setMaximumSize(buttonSize);
-    cbEscapeSeq->setIcon(getRealIconCached("escape"));
+	cbEscapeSeq->setMinimumSize(buttonSize);
+	cbEscapeSeq->setMaximumSize(buttonSize);
+	cbEscapeSeq->setIcon(getRealIconCached("escape"));
 	CONFIG_DECLARE_OPTION_WITH_OBJECT(conf, bool, escapeConfig, false, "Search/Escape Sequence", cbEscapeSeq);
-    flowLayout2->addWidget(cbEscapeSeq);
+	flowLayout2->addWidget(cbEscapeSeq);
 
-    lReplacementText = new QLabel(this);
-    lReplacementText->setTextFormat(Qt::PlainText);
-    lReplacementText->setMinimumHeight(buttonSize.height());
-    int numButtonSpread = 5;
-    int lReplacementSize = numButtonSpread * buttonSize.width() + (numButtonSpread-1) * flowLayout2->horizontalSpacing();
-    // fixed size needed: unrestricted width would lead to shifting replace buttons
-    lReplacementText->setMinimumWidth(lReplacementSize);
-    lReplacementText->setMaximumWidth(lReplacementSize);
-    flowLayout2->addWidget(lReplacementText);
+	lReplacementText = new QLabel(this);
+	lReplacementText->setTextFormat(Qt::PlainText);
+	lReplacementText->setMinimumHeight(buttonSize.height());
+	int numButtonSpread = 5;
+	int lReplacementSize = numButtonSpread * buttonSize.width() + (numButtonSpread-1) * flowLayout2->horizontalSpacing();
+	// fixed size needed: unrestricted width would lead to shifting replace buttons
+	lReplacementText->setMinimumWidth(lReplacementSize);
+	lReplacementText->setMaximumWidth(lReplacementSize);
+	flowLayout2->addWidget(lReplacementText);
 
 
 	//retranslateUi(this);
@@ -324,26 +344,26 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	connect(cReplace->lineEdit(),SIGNAL(textEdited(QString)),SLOT(cReplace_textEdited(QString)));
 
 	// set texts
-    bClose->setToolTip(tr("Close search/replace panel"));
-    cFind->setToolTip(tr("Text or pattern to search for"));
-    bNext->setToolTip(tr("Find next"));
-    bPrevious->setToolTip(tr("Find previous"));
-    bCount->setToolTip(tr("Count occurences"));
-    cReplace->setToolTip(tr("Replacement text"));
-    bReplaceNext->setToolTip(tr("Replace and find next"));
-    bReplacePrevious->setToolTip(tr("Replace and find previous"));
-    bReplaceAll->setToolTip(tr("Replace all"));
+	bClose->setToolTip(tr("Close search/replace panel"));
+	cFind->setToolTip(tr("Text or pattern to search for"));
+	bNext->setToolTip(tr("Find next"));
+	bPrevious->setToolTip(tr("Find previous"));
+	bCount->setToolTip(tr("Count occurrences"));
+	cReplace->setToolTip(tr("Replacement text"));
+	bReplaceNext->setToolTip(tr("Replace and find next"));
+	bReplacePrevious->setToolTip(tr("Replace and find previous"));
+	bReplaceAll->setToolTip(tr("Replace all"));
 
-    lbFind->setText(tr("Find:"));
-    lbReplace->setText(tr("Replace:"));
-    int wd=qMax(lbFind->sizeHint().width(),lbReplace->sizeHint().width());
-    lbFind->setMinimumWidth(wd);
-    lbReplace->setMinimumWidth(wd);
-    lbFind->setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred);
-    lbReplace->setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred);
+	lbFind->setText(tr("Find:"));
+	lbReplace->setText(tr("Replace:"));
+	int wd=qMax(lbFind->sizeHint().width(),lbReplace->sizeHint().width());
+	lbFind->setMinimumWidth(wd);
+	lbReplace->setMinimumWidth(wd);
+	lbFind->setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred);
+	lbReplace->setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred);
 
 
-    cFind->installEventFilter(this);
+	cFind->installEventFilter(this);
 	cReplace->installEventFilter(this);
 	Q_ASSERT(cFind->completer()->popup());
 	cFind->completer()->popup()->installEventFilter(this);
@@ -355,8 +375,8 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 */
 QSearchReplacePanel::~QSearchReplacePanel()
 {
-    delete m_search;
-    m_search=nullptr;
+	delete m_search;
+	m_search=nullptr;
 }
 
 /*!
@@ -400,13 +420,13 @@ void QSearchReplacePanel::editorChange(QEditor *e)
 	if ( editor() )
 	{
 		disconnect(	editor(), SIGNAL( cursorPositionChanged() ),
-					this	, SLOT  ( cursorPositionChanged() ) );
+		            this	, SLOT  ( cursorPositionChanged() ) );
 	}
 
 	if ( e )
 	{
 		connect(e	, SIGNAL( cursorPositionChanged() ),
-				this, SLOT  ( cursorPositionChanged() ) );
+		        this, SLOT  ( cursorPositionChanged() ) );
 	}
 }
 
@@ -427,7 +447,7 @@ bool QSearchReplacePanel::forward(QMouseEvent *e)
 void QSearchReplacePanel::display(int mode, bool replace)
 {
 	//qDebug("display(%i)", replace);
-        if (! m_search) init();
+	if (! m_search) init();
 
 	bool visible = true;
 
@@ -445,10 +465,10 @@ void QSearchReplacePanel::display(int mode, bool replace)
 
 		bool focusFindEdit = true;
 		if (m_search){
-            // save current cursor position
-            m_initialCursorPos.push(editor()->cursor());
+			// save current cursor position
+			m_initialCursorPos.push(editor()->cursor());
 			if(editor()->cursor().hasSelection()){
-                if(editor()->cursor().anchorLineNumber()!=editor()->cursor().lineNumber() || !useLineForSearch){
+				if(editor()->cursor().anchorLineNumber()!=editor()->cursor().lineNumber() || !useLineForSearch){
 					if (searchOnlyInSelection){
 						if(cbSelection->isChecked()) on_cbSelection_toggled(true);
 						else cbSelection->setChecked(true);
@@ -460,7 +480,7 @@ void QSearchReplacePanel::display(int mode, bool replace)
 				} else {
 					// single line selection
 					// copy content to cFind (doesn't trigger textEdited; don't call textEdited to prevent cursor jumping)
-                    cbSelection->setChecked(false);
+					cbSelection->setChecked(false);
 					cFind->setEditText(editor()->cursor().selectedText());
 					m_search->setSearchText(cFind->currentText());
 				}
@@ -486,15 +506,15 @@ void QSearchReplacePanel::display(int mode, bool replace)
 			cReplace->lineEdit()->selectAll();
 		}
 		//show();
-    }else closeEvent(nullptr);
-		
+	}else closeEvent(nullptr);
+
 	setVisible(visible);
 
-    if ( !visible ){
-        m_initialCursorPos.clear();
+	if ( !visible ){
+		m_initialCursorPos.clear();
 		editor()->setFocus();
-        bExtend->setChecked(false);
-    }
+		bExtend->setChecked(false);
+	}
 }
 
 void QSearchReplacePanel::closeElement(bool closeTogether){
@@ -504,7 +524,7 @@ void QSearchReplacePanel::closeElement(bool closeTogether){
 		if (qobject_cast<QWidget*>(o)) qDebug() << "   "<<(qobject_cast<QWidget*>(o))->hasFocus()<<(qobject_cast<QWidget*>(o))->isVisible();
 		foreach (QObject* p, o->children()) {
 			qDebug()<<"child child  "<<p;
-			if (qobject_cast<QWidget*>(p)) 
+			if (qobject_cast<QWidget*>(p))
 				qDebug() << "   "<<(qobject_cast<QWidget*>(p))->hasFocus()
 				<<(qobject_cast<QWidget*>(p))->isVisible();
 			foreach (QObject* q, p->children()) {
@@ -517,10 +537,10 @@ void QSearchReplacePanel::closeElement(bool closeTogether){
 		cFind->setFocus();
 	else if (cReplace->completer()->popup()->isVisible() && cReplace->completer()->popup()->hasFocus())
 		cReplace->setFocus();
-	else if (isReplaceModeActive() & !closeTogether)
+	else if (isReplaceModeActive() && !closeTogether)
 		display(1,false);
 	else
-		display(0,false);	
+		display(0,false);
 }
 
 void QSearchReplacePanel::findNext(){
@@ -562,7 +582,7 @@ void QSearchReplacePanel::rememberLastSearch(QStringList& history, const QString
 		ConfigManagerInterface::getInstance()->updateAllLinkedObjects(&history);
 	}
 }
-	
+
 void QSearchReplacePanel::findReplace(bool backward, bool replace, bool replaceAll, bool countOnly)
 {
 	Q_ASSERT(!(replace && countOnly));
@@ -573,7 +593,7 @@ void QSearchReplacePanel::findReplace(bool backward, bool replace, bool replaceA
 		return;
 	}
 
-	updateSearchOptions(replace,replaceAll);;
+	updateSearchOptions(replace,replaceAll);
 	m_lastDirection=backward;
 
 	if (!countOnly)  m_search->next(backward, replaceAll, !cbPrompt->isChecked(), true);
@@ -597,17 +617,17 @@ void QSearchReplacePanel::findReplace(bool backward, bool replace, bool replaceA
 	}
 	rememberLastSearch(findHistory,cFind->currentText(),m_search->options() & QDocumentSearch::Silent);
 	rememberLastSearch(replaceHistory,cReplace->currentText(),m_search->options() & QDocumentSearch::Silent);
-    /*if (isVisible() && !cbHasFocus(cFind) && !cbHasFocus(cReplace) ) {
+	/*if (isVisible() && !cbHasFocus(cFind) && !cbHasFocus(cReplace) ) {
 		if (replace) cReplace->setFocus();
 		else cFind->setFocus();
-    }*/
+		}*/
 	updateReplacementHint();
 }
 
 void QSearchReplacePanel::find(QString text, bool backward, bool highlight, bool regex, bool word, bool caseSensitive, bool fromCursor, bool selection){
-    cbSelection->setChecked(selection);
-    cbCursor->setChecked(fromCursor);
-    find(text, backward, highlight, regex, word, caseSensitive);
+	cbSelection->setChecked(selection);
+	cbCursor->setChecked(fromCursor);
+	find(text, backward, highlight, regex, word, caseSensitive);
 }
 
 void QSearchReplacePanel::selectAllMatches(){
@@ -639,7 +659,7 @@ void QSearchReplacePanel::find(QString text, bool backward, bool highlight, bool
 	if (!isVisible()) display(1,false);
 	if (m_search && m_search->searchText()!=text) {
 		delete m_search;
-        m_search=nullptr;
+		m_search=nullptr;
 	}
 	//if (!m_search) editor()->setCursorPosition(0,0); ??
 	if(!m_search) init();
@@ -670,7 +690,7 @@ void QSearchReplacePanel::hideEvent(QHideEvent *)
 
 void QSearchReplacePanel::showEvent(QShowEvent *)
 {
-    updateButtonSizes();
+	updateButtonSizes();
 }
 
 
@@ -700,17 +720,17 @@ void QSearchReplacePanel::closeEvent(QCloseEvent *)
 
 bool QSearchReplacePanel::eventFilter(QObject *o, QEvent *e)
 {
-//	if (e->type() == QEvent::KeyPress)
-//		qDebug() << QDateTime::currentDateTime() << "eventfilter:" << o << (o?o->objectName():"..") << " vs. " << cFind->completer()->popup();
+	//	if (e->type() == QEvent::KeyPress)
+	//		qDebug() << QDateTime::currentDateTime() << "eventfilter:" << o << (o?o->objectName():"..") << " vs. " << cFind->completer()->popup();
 	if ( o == cFind || o == cReplace )
 	{
 		int kc;
 		switch ( e->type() )
 		{
-			/*
+		/*
 			case QEvent::FocusIn :
 				cFind->grabKeyboard();
-                                break;*/
+																break;*/
 
 		/*	case QEvent::FocusOut :
 				e->setAccepted(true);
@@ -719,40 +739,40 @@ bool QSearchReplacePanel::eventFilter(QObject *o, QEvent *e)
 				//break;
 			*/
 
-			case QEvent::KeyPress :
+		case QEvent::KeyPress :
 
-				kc = static_cast<QKeyEvent*>(e)->key();
-				if ( ( (kc == Qt::Key_Enter) || (kc == Qt::Key_Return) ) )
+			kc = static_cast<QKeyEvent*>(e)->key();
+			if ( ( (kc == Qt::Key_Enter) || (kc == Qt::Key_Return) ) )
+			{
+				//on_cFind_returnPressed();
+				if (cbHasFocus(cReplace))
+					on_cReplace_returnPressed(Qt::ShiftModifier & static_cast<QKeyEvent*>(e)->modifiers());
+				else
+					on_cFind_returnPressed(Qt::ShiftModifier & static_cast<QKeyEvent*>(e)->modifiers());
+				return true;
+			} else if ( kc == Qt::Key_Escape) {
+				if ( isReplaceModeActive() )
+					display(0,false);
+				else
+					display(0,false);
+				return true;
+			} else if ( kc == Qt::Key_Tab || kc == Qt::Key_Backtab ) {
+				if ( isReplaceModeActive() )
 				{
-					//on_cFind_returnPressed();
-					if (cbHasFocus(cReplace)) 
-						on_cReplace_returnPressed(Qt::ShiftModifier & static_cast<QKeyEvent*>(e)->modifiers());
-					else
-						on_cFind_returnPressed(Qt::ShiftModifier & static_cast<QKeyEvent*>(e)->modifiers());
-					return true;
-				} else if ( kc == Qt::Key_Escape) {
-					if ( isReplaceModeActive() )
-						display(0,false);
-					else
-						display(0,false);
-					return true;
-				} else if ( kc == Qt::Key_Tab || kc == Qt::Key_Backtab ) {
-					if ( isReplaceModeActive() )
-					{
-						if ( cbHasFocus(cFind) ) {
-							cReplace->setFocus();
-							cReplace->lineEdit()->selectAll();
-						} else {
-							cFind->setFocus();
-							cFind->lineEdit()->selectAll();
-						}
+					if ( cbHasFocus(cFind) ) {
+						cReplace->setFocus();
+						cReplace->lineEdit()->selectAll();
+					} else {
+						cFind->setFocus();
+						cFind->lineEdit()->selectAll();
 					}
-					return true;
 				}
-				break;
+				return true;
+			}
+			break;
 
-			default:
-				break;
+		default:
+			break;
 		}
 	} else if ( o == cFind->completer()->popup() || o == cReplace->completer()->popup() ) {
 		int kc;
@@ -764,7 +784,7 @@ bool QSearchReplacePanel::eventFilter(QObject *o, QEvent *e)
 			if ( (kc == Qt::Key_Enter) || (kc == Qt::Key_Return) )
 			{
 				//on_cFind_returnPressed();
-				if (cbHasFocus(cReplace)) 
+				if (cbHasFocus(cReplace))
 					on_cReplace_returnPressed(Qt::ShiftModifier & static_cast<QKeyEvent*>(e)->modifiers());
 				else
 					on_cFind_returnPressed(Qt::ShiftModifier & static_cast<QKeyEvent*>(e)->modifiers());
@@ -790,55 +810,55 @@ bool QSearchReplacePanel::eventFilter(QObject *o, QEvent *e)
 }
 
 void QSearchReplacePanel::updateButtonSizes(){
-    QSize buttonSize(cFind->height(),cFind->height());
-    bNext->setMinimumSize(buttonSize);
-    bNext->setMaximumSize(buttonSize);
-    bNext->setIconSize(buttonSize);
-    bPrevious->setMinimumSize(buttonSize);
-    bPrevious->setMaximumSize(buttonSize);
-    bPrevious->setIconSize(buttonSize);
-    bCount->setMinimumSize(buttonSize);
-    bCount->setMaximumSize(buttonSize);
-    bCount->setIconSize(buttonSize);
-    cbCase->setMinimumSize(buttonSize);
-    cbCase->setMaximumSize(buttonSize);
-    cbCase->setIconSize(buttonSize);
-    cbWords->setMinimumSize(buttonSize);
-    cbWords->setMaximumSize(buttonSize);
-    cbWords->setIconSize(buttonSize);
-    cbCursor->setMinimumSize(buttonSize);
-    cbCursor->setMaximumSize(buttonSize);
-    cbCursor->setIconSize(buttonSize);
-    cbRegExp->setMinimumSize(buttonSize);
-    cbRegExp->setMaximumSize(buttonSize);
-    cbRegExp->setIconSize(buttonSize);
-    cbHighlight->setMinimumSize(buttonSize);
-    cbHighlight->setMaximumSize(buttonSize);
-    cbHighlight->setIconSize(buttonSize);
-    cbSelection->setMinimumSize(buttonSize);
-    cbSelection->setMaximumSize(buttonSize);
-    cbSelection->setIconSize(buttonSize);
-    bExtend->setMinimumSize(buttonSize);
-    bExtend->setMaximumSize(buttonSize);
-    bExtend->setIconSize(buttonSize);
+	QSize buttonSize(cFind->height(),cFind->height());
+	bNext->setMinimumSize(buttonSize);
+	bNext->setMaximumSize(buttonSize);
+	bNext->setIconSize(buttonSize);
+	bPrevious->setMinimumSize(buttonSize);
+	bPrevious->setMaximumSize(buttonSize);
+	bPrevious->setIconSize(buttonSize);
+	bCount->setMinimumSize(buttonSize);
+	bCount->setMaximumSize(buttonSize);
+	bCount->setIconSize(buttonSize);
+	cbCase->setMinimumSize(buttonSize);
+	cbCase->setMaximumSize(buttonSize);
+	cbCase->setIconSize(buttonSize);
+	cbWords->setMinimumSize(buttonSize);
+	cbWords->setMaximumSize(buttonSize);
+	cbWords->setIconSize(buttonSize);
+	cbCursor->setMinimumSize(buttonSize);
+	cbCursor->setMaximumSize(buttonSize);
+	cbCursor->setIconSize(buttonSize);
+	cbRegExp->setMinimumSize(buttonSize);
+	cbRegExp->setMaximumSize(buttonSize);
+	cbRegExp->setIconSize(buttonSize);
+	cbHighlight->setMinimumSize(buttonSize);
+	cbHighlight->setMaximumSize(buttonSize);
+	cbHighlight->setIconSize(buttonSize);
+	cbSelection->setMinimumSize(buttonSize);
+	cbSelection->setMaximumSize(buttonSize);
+	cbSelection->setIconSize(buttonSize);
+	bExtend->setMinimumSize(buttonSize);
+	bExtend->setMaximumSize(buttonSize);
+	bExtend->setIconSize(buttonSize);
 }
 
 void QSearchReplacePanel::cFind_textEdited(const QString& text)
 { 
 	if (! m_search) init();
 	
-    if(m_search->searchText().length()==text.length()+1 && m_search->searchText().startsWith(text)){
-        // last letter removed (backspace)
-        QDocumentCursor cur=m_initialCursorPos.top();
-        if(m_initialCursorPos.size()>1){
-            m_initialCursorPos.pop();
-        }
-        m_search->setCursor(cur);
-    }else{
-        if(m_search->searchText()!=text){
-            m_initialCursorPos.push(editor()->cursor());
-        }
-    }
+	if(m_search->searchText().length()==text.length()+1 && m_search->searchText().startsWith(text)){
+		// last letter removed (backspace)
+		QDocumentCursor cur=m_initialCursorPos.top();
+		if(m_initialCursorPos.size()>1){
+			m_initialCursorPos.pop();
+		}
+		m_search->setCursor(cur);
+	}else{
+		if(m_search->searchText()!=text){
+			m_initialCursorPos.push(editor()->cursor());
+		}
+	}
 	m_search->setSearchText(text);
 	
 	if ( text.isEmpty() )
@@ -858,12 +878,12 @@ void QSearchReplacePanel::cFind_textEdited(const QString& text)
 	
 	findReplace(false);
 	
-	m_search->setOption(QDocumentSearch::Silent,false);	
+	m_search->setOption(QDocumentSearch::Silent,false);
 	
 	if ( m_search->cursor().isNull() )
 		cFind->lineEdit()->setStyleSheet("QLineEdit { background: red; color : white; }");
-	else if ((m_search->cursor().anchorLineNumber() < cur.anchorLineNumber()) || 
-			(m_search->cursor().anchorLineNumber() == cur.anchorLineNumber() && m_search->cursor().anchorColumnNumber()<cur.anchorColumnNumber())) {
+	else if ((m_search->cursor().anchorLineNumber() < cur.anchorLineNumber()) ||
+	         (m_search->cursor().anchorLineNumber() == cur.anchorLineNumber() && m_search->cursor().anchorColumnNumber()<cur.anchorColumnNumber())) {
 		cFind->lineEdit()->setStyleSheet("QLineEdit { background: yellow; color : black; }");
 		editor()->setCursor(m_search->cursor());
 	} else {
@@ -901,11 +921,38 @@ void QSearchReplacePanel::on_cbPrompt_toggled(bool on){
 		cFind->setFocus();
 }
 
+void QSearchReplacePanel::setFilteredIconAndFormats(const char* icon, const std::initializer_list<const char*>& formats, bool inverted){
+	QDocument *doc=editor()->document();
+	REQUIRE(doc);
+	cbFilter->setIcon(getRealIconCached(icon));
+	QList<int> ids;
+	for (const char * fmt : formats)
+		ids << doc->getFormatId(fmt);
+	m_search->setFilteredFormats(ids, inverted);
+}
+
+
+void QSearchReplacePanel::filterChanged()
+{
+	QAction *act=qobject_cast<QAction*>(sender());
+	if(act==nullptr)
+		return;
+	QString text=act->text();
+	if(text=="all") setFilteredIconAndFormats("all", {});
+	else if(text=="math") setFilteredIconAndFormats("math", {"numbers", "math-keyword", "math-delimiter"});
+	else if(text=="verbatim") setFilteredIconAndFormats("verbatim", {"verbatim"});
+	else if(text=="comment") setFilteredIconAndFormats("comment", {"comment"});
+	else if(text=="non-comment") setFilteredIconAndFormats("non-comment", {"comment"}, true);
+	else if(text=="keyword") setFilteredIconAndFormats("command", {"keyword", "extra-keyword", "math-keyword"});
+	else if(text=="label") setFilteredIconAndFormats("label", {"referencePresent","referenceMissing","referenceMultiple"});
+	else if(text=="citation") setFilteredIconAndFormats("cite", {"citationPresent","citationMissing"});
+}
+
 void QSearchReplacePanel::on_cbWords_toggled(bool on)
 {
 	if ( m_search )
 		m_search->setOption(QDocumentSearch::WholeWords, on);
-	if (on && cbRegExp->isChecked()) 
+	if (on && cbRegExp->isChecked())
 		cbRegExp->setChecked(false); //word and regexp is not possible
 	if ( cFind->isVisible() )
 		cFind->setFocus();
@@ -915,7 +962,7 @@ void QSearchReplacePanel::on_cbRegExp_toggled(bool on)
 {
 	if ( m_search )
 		m_search->setOption(QDocumentSearch::RegExp, on);
-	if (on && cbWords->isChecked()) 
+	if (on && cbWords->isChecked())
 		cbWords->setChecked(false); //word and regexp is not possible
 	if ( cFind->isVisible() )
 		cFind->setFocus();
@@ -963,14 +1010,14 @@ void QSearchReplacePanel::on_cbSelection_toggled(bool on)
 {
 	if ( m_search ) {
 		m_search->setScope(on ? editor()->cursor() : QDocumentCursor());
-        if(on){
-            // deselect cursor to show search scope (which is below cuersor highlight)
-            QDocumentCursor cur=editor()->cursor();
-            if(cur.hasSelection()){
-                cur.clearSelection();
-                editor()->setCursor(cur);
-            }
-        }
+		if(on){
+			// deselect cursor to show search scope (which is below cuersor highlight)
+			QDocumentCursor cur=editor()->cursor();
+			if(cur.hasSelection()){
+				cur.clearSelection();
+				editor()->setCursor(cur);
+			}
+		}
 	}
 	cFind->setFocus();
 }
@@ -1017,8 +1064,8 @@ void QSearchReplacePanel::on_bReplacePrevious_clicked()
 
 void QSearchReplacePanel::on_bReplaceAll_clicked()
 {
-	 cFind->lineEdit()->setStyleSheet(QString());
-	 findReplace(false,true,true);
+	cFind->lineEdit()->setStyleSheet(QString());
+	findReplace(false,true,true);
 }
 
 void QSearchReplacePanel::init()
@@ -1026,7 +1073,7 @@ void QSearchReplacePanel::init()
 	if ( m_search )
 	{
 		delete m_search;
-        m_search = nullptr;
+		m_search = nullptr;
 	}
 
 	QDocumentSearch::Options opt;
@@ -1047,20 +1094,20 @@ void QSearchReplacePanel::init()
 		opt |= QDocumentSearch::Replace;
 
 	if ( cbPrompt->isChecked() )
-        	opt |= QDocumentSearch::Prompt;
+		opt |= QDocumentSearch::Prompt;
 
 	if ( cbEscapeSeq->isChecked() )
-        	opt |= QDocumentSearch::EscapeSeq;
+		opt |= QDocumentSearch::EscapeSeq;
 	
 	m_search = new QDocumentSearch(	editor(),
-									cFind->currentText(),
-									opt,
-									isReplaceModeActive()
-										?
-											cReplace->currentText()
-										:
-											QString()
-									);
+	                                cFind->currentText(),
+	                                opt,
+	                                isReplaceModeActive()
+	                                ?
+	                                  cReplace->currentText()
+	                                :
+	                                  QString()
+	                                  );
 
 
 	if ( cbSelection->isChecked() && editor()->cursor().hasSelection()){
@@ -1086,7 +1133,7 @@ void QSearchReplacePanel::cursorPositionChanged()
 				m_search->setCursor(editor()->cursor());
 		}*/
 		if ( cbCursor->isChecked() )
-				m_search->setCursor(editor()->cursor());
+			m_search->setCursor(editor()->cursor());
 	}
 }
 
@@ -1103,27 +1150,27 @@ void QSearchReplacePanel::updateReplacementHint(){
 }
 
 QString QSearchReplacePanel::getSearchText() const{
-    return cFind->currentText();
+	return cFind->currentText();
 }
 
 QString QSearchReplacePanel::getReplaceText() const
 {
-    return cReplace->currentText();
+	return cReplace->currentText();
 }
 
 bool QSearchReplacePanel::getSearchIsCase() const
 {
-    return cbCase->isChecked();
+	return cbCase->isChecked();
 }
 
 bool QSearchReplacePanel::getSearchIsWords() const
 {
-    return cbWords->isChecked();
+	return cbWords->isChecked();
 }
 
 bool QSearchReplacePanel::getSearchIsRegExp() const
 {
-    return cbRegExp->isChecked();
+	return cbRegExp->isChecked();
 }
 
 
