@@ -15,7 +15,7 @@ QStringList LatexTables::mathTables = QStringList() << "align" << "align*" << "a
                                       << "gather" << "gather*" << "flalign" << "flalign*" << "alignat" << "alignat*"
                                       << "cases" << "aligned" << "gathered" << "alignedat";
 
-QSet<QString> environmentsRequiringTrailingLineBreak = QSet<QString>() << "supertabular";
+static QSet<QString> environmentsRequiringTrailingLineBreak = QSet<QString>() << "supertabular";
 // Note: Apparently some environments always require a line break "\\". These should be specified here.
 // Some don't want one, e.g. align, blockarray, ...
 // And some can cope with both cases, e.g. tabular
@@ -310,7 +310,7 @@ void LatexTables::removeColumn(QDocument *doc, const int lineNumber, const int c
 							}
 						}
 					}
-					if (keep.length() == 1) keep.clear();;
+                    if (keep.length() == 1) keep.clear();
 				}
 				cur.removeSelectedText();
 				if (column > 0) {
@@ -907,6 +907,7 @@ LatexTableModel::LatexTableModel(QObject *parent) : QAbstractTableModel(parent),
 	ConfigManagerInterface *cfg = ConfigManager::getInstance();
 	if (cfg) {
 		metaLineCommands = cfg->getOption("TableAutoformat/Special Commands").toString().split(',');
+		metaLineCommands.removeAll("");  // make sure there are no empty commands due to double or trailing comma
 		metaLineCommandPos = cfg->getOption("TableAutoformat/Special Command Position").toInt();
 	}
 }
