@@ -1,8 +1,8 @@
 #ifndef QT_NO_DEBUG
 #include "testutil.h"
 namespace QTest{
-MessageBoxCloser* curCloser=0;
-MessageBoxCloser::MessageBoxCloser(bool mustExists, QMessageBox::StandardButton button):QObject(0), m_mustExists(mustExists), m_button(button){
+MessageBoxCloser* curCloser=nullptr;
+MessageBoxCloser::MessageBoxCloser(bool mustExists, QMessageBox::StandardButton button):QObject(nullptr), m_mustExists(mustExists), m_button(button){
 	if (button!=QMessageBox::Ok && button!=QMessageBox::Cancel && button!=QMessageBox::NoButton && button!=QMessageBox::Yes)
 		QVERIFY2(false, "invalid button for messagebox closing");
 	QTimer::singleShot(1, this, SLOT(closeNow()));
@@ -27,7 +27,7 @@ void MessageBoxCloser::closeNow(){
 			QTest::keyClick(messageWindow, Qt::Key_Escape);
 			break;
 	}	
-	curCloser=0;
+    curCloser=nullptr;
 }
 void closeMessageBoxLater(bool mustExists, QMessageBox::StandardButton button){
 	if (curCloser) QWARN("multiple closing calls");
