@@ -86,9 +86,9 @@ public slots:
 	void hideSplash(); ///< hide splash screen
 	void startupCompleted();
 	void onOtherInstanceMessage(const QString &);  ///< For messages for the single instance
-
 	void fuzzCursorHistory();
 	void fuzzBackForward();
+    void setBuildButtonsDisabled(bool c);
 
 
 protected:
@@ -106,6 +106,7 @@ protected:
     Q_INVOKABLE QAction *insertManagedAction(QAction *before, const QString &id, const QString &text, const char *slotName = nullptr, const QKeySequence &shortCut = 0, const QString &iconFile = "");
 
 	void addTagList(const QString &id, const QString &iconName, const QString &text, const QString &tagFile);
+    void addMacrosAsTagList();
 
 private slots:
 	void updateToolBarMenu(const QString &menuName);
@@ -153,6 +154,8 @@ private:
 	LatexParser latexParser;
 public:
 	LatexDocuments documents;
+
+    Q_INVOKABLE bool completerIsVisible();
 private:
 	OutputViewWidget *outputView; ///< contains output widgets (over OutputLayout)
 
@@ -201,6 +204,7 @@ private:
 	void configureNewEditorView(LatexEditorView *edit);
 	void configureNewEditorViewEnd(LatexEditorView *edit, bool asMaster = false, bool hidden = false);
 	LatexEditorView *getEditorViewFromFileName(const QString &fileName, bool checkTemporaryNames = false);
+	LatexEditorView *getEditorViewFromHandle(const QDocumentLineHandle *dlh);
 
 	QAction *fullscreenModeAction;
 
@@ -367,6 +371,7 @@ protected slots:
 	void insertXmlTagFromToolButtonAction();
 	void callToolButtonAction();
 	void insertFromAction();
+    void insertFromTagList(QListWidgetItem *item);
 	void insertBib();
 	void closeEnvironment();
 
@@ -411,6 +416,7 @@ protected slots:
 	bool checkProgramPermission(const QString &program, const QString &cmdId, LatexDocument *master);
 	void runInternalPdfViewer(const QFileInfo &master, const QString &options);
 	void runBibliographyIfNecessary(const QFileInfo &cmd);
+	QDateTime GetBblLastModified(void);
 
 	void showExtendedSearch();
 
@@ -631,8 +637,6 @@ protected:
 
     bool rememberFollowFromScroll,enlargedViewer;
 
-	LatexEditorView *editorViewForLabel(LatexDocument *doc, const QString &label);
-
 	QSet<QString> latexPackageList, currentPackageList;
 
 	QMap<QString, QString> *mReplacementList;
