@@ -12,7 +12,7 @@
 bool getDiskFreeSpace(const QString &path, quint64 &freeBytes)
 {
 #ifdef Q_OS_WIN
-	wchar_t d[path.size() + 1];
+	wchar_t* d = new wchar_t[path.size() + 1];
 	int len = path.toWCharArray(d);
 	d[len] = 0;
 
@@ -20,14 +20,16 @@ bool getDiskFreeSpace(const QString &path, quint64 &freeBytes)
 	freeBytesToCaller.QuadPart = 0L;
 
 	if ( !GetDiskFreeSpaceEx( d, &freeBytesToCaller, NULL, NULL ) ) {
+        delete[] d;
 		qDebug() << "ERROR: Call to GetDiskFreeSpaceEx() failed on path" << path;
 		return false;
 	}
+    delete[] d;
 	freeBytes = freeBytesToCaller.QuadPart;
 	return true;
 #else
-	Q_UNUSED(path);
-	Q_UNUSED(freeBytes);
+	Q_UNUSED(path)
+	Q_UNUSED(freeBytes)
 	return false;
 #endif
 }
@@ -78,6 +80,7 @@ QKeySequence filterLocaleShortcut(QKeySequence ks)
 		} else if (ks.matches(QKeySequence("Ctrl+Alt+L"))) {
 			return QKeySequence("Ctrl+Alt+Shift+L");
 		}
+		break;
 	case QLocale::Croatian:
 		if (ks.matches(QKeySequence("Ctrl+Alt+F"))) {
 			return QKeySequence("Ctrl+Alt+Shift+F");
@@ -134,6 +137,7 @@ QStringList findResourceFiles(const QString &dirName, const QString &filter, QSt
 	if (!dn.startsWith('/') && !dn.startsWith(QDir::separator())) dn = "/" + dn; //add / at beginning
 	searchFiles << ":" + dn; //resource fall back
 	searchFiles.append(additionalPreferredPaths);
+    searchFiles << QCoreApplication::applicationDirPath() + "/../share/texstudio"; //appimage relative path
 	searchFiles << QCoreApplication::applicationDirPath() + dn; //windows new
     searchFiles << QCoreApplication::applicationDirPath() + "/"; //windows old
     searchFiles << QCoreApplication::applicationDirPath() + "/dictionaries/"; //windows new
@@ -190,6 +194,7 @@ QString findResourceFile(const QString &fileName, bool allowOverride, QStringLis
 		else searchFiles << s + "/";
 #if defined Q_WS_X11 || defined Q_OS_LINUX || defined Q_OS_UNIX
 	searchFiles << PREFIX"/share/texstudio/"; //X_11
+    searchFiles << QCoreApplication::applicationDirPath() + "/../share/texstudio/"; // relative path for appimage
 	if (fileName.endsWith(".html")) searchFiles << PREFIX"/share/doc/texstudio/html/"; //for Debian package
 #endif
 #ifdef Q_OS_MAC
@@ -350,9 +355,9 @@ QString joinPath(const QString &dirname, const QString &dirname2, const QString
 /// Does nothing on Windows.
 QFileInfo getNonSymbolicFileInfo(const QFileInfo& info)
 {
-	const size_t MAX_DIR_DEPTH=32; //< Do not seek for symbolic links deeper than MAX_DIR_DEPTH.
-									// For performance issues and if the root directory was not catched (infinite loop).
 #ifdef Q_OS_UNIX
+	const size_t MAX_DIR_DEPTH=32; //< Do not seek for symbolic links deeper than MAX_DIR_DEPTH.
+	                               // For performance issues and if the root directory was not catched (infinite loop).
 	// Static array might be also used to prevent heap allocation for a small amont of data. QFileInfo is shared, so the size of the array is size_of(void*)*MAX_DIR_DEPTH
 	//QFileInfo stack[MAX_DIR_DEPTH];
 	QStack<QFileInfo> stack;
@@ -671,25 +676,7 @@ QStringList envKeys(const QProcessEnvironment &env)
 #endif
 }
 
-// run the command in a separate process, wait and return the result
-// use for internal queries that should be silent. Not to be mixed up with BuildManager::runCommand
-QString execCommand(const QString &cmd, QString additionalPaths)
-{
-	if (cmd.isEmpty()) return QString();
-    QProcess myProc(nullptr);
-    if(!additionalPaths.isEmpty()){
-        updatePathSettings(&myProc,additionalPaths);
-    }
-	myProc.start(cmd);
-	myProc.waitForFinished();
-	QString result;
-	if (myProc.exitCode() == 0) {
-		result = myProc.readAllStandardOutput();
-	}
-	return result.trimmed();
-}
-
-void ThreadBreaker::sleep(int s)
+void ThreadBreaker::sleep(unsigned long s)
 {
 	QThread::sleep(s);
 }
